# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupMetricRuleArgs', 'GroupMetricRule']

@pulumi.input_type
class GroupMetricRuleArgs:
    def __init__(__self__, *,
                 escalations: pulumi.Input['GroupMetricRuleEscalationsArgs'],
                 group_id: pulumi.Input[str],
                 group_metric_rule_name: pulumi.Input[str],
                 metric_name: pulumi.Input[str],
                 namespace: pulumi.Input[str],
                 rule_id: pulumi.Input[str],
                 category: Optional[pulumi.Input[str]] = None,
                 contact_groups: Optional[pulumi.Input[str]] = None,
                 dimensions: Optional[pulumi.Input[str]] = None,
                 effective_interval: Optional[pulumi.Input[str]] = None,
                 email_subject: Optional[pulumi.Input[str]] = None,
                 interval: Optional[pulumi.Input[str]] = None,
                 no_effective_interval: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input['GroupMetricRuleTargetArgs']]]] = None,
                 webhook: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a GroupMetricRule resource.
        :param pulumi.Input['GroupMetricRuleEscalationsArgs'] escalations: Alarm level. See `escalations` below.
        :param pulumi.Input[str] group_id: The ID of the application group.
        :param pulumi.Input[str] group_metric_rule_name: The name of the alert rule.
        :param pulumi.Input[str] metric_name: The name of the metric.
        :param pulumi.Input[str] namespace: The namespace of the service.
        :param pulumi.Input[str] rule_id: The ID of the alert rule.
        :param pulumi.Input[str] category: The abbreviation of the service name.
        :param pulumi.Input[str] contact_groups: Alarm contact group.
        :param pulumi.Input[str] dimensions: The dimensions that specify the resources to be associated with the alert rule.
        :param pulumi.Input[str] effective_interval: The time period during which the alert rule is effective.
        :param pulumi.Input[str] email_subject: The subject of the alert notification email.
        :param pulumi.Input[str] interval: The interval at which Cloud Monitor checks whether the alert rule is triggered. Unit: seconds.
        :param pulumi.Input[str] no_effective_interval: The time period during which the alert rule is ineffective.
        :param pulumi.Input[int] period: The aggregation period of the monitoring data. Unit: seconds. The value is an integral multiple of 60. Default value: `300`.
        :param pulumi.Input[int] silence_time: The mute period during which new alerts are not reported even if the alert trigger conditions are met. Unit: seconds. Default value: `86400`, which is equivalent to one day.
        :param pulumi.Input[Sequence[pulumi.Input['GroupMetricRuleTargetArgs']]] targets: The information about the resource for which alerts are triggered. See `targets` below.
        :param pulumi.Input[str] webhook: The callback URL.
        """
        pulumi.set(__self__, "escalations", escalations)
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "group_metric_rule_name", group_metric_rule_name)
        pulumi.set(__self__, "metric_name", metric_name)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "rule_id", rule_id)
        if category is not None:
            pulumi.set(__self__, "category", category)
        if contact_groups is not None:
            pulumi.set(__self__, "contact_groups", contact_groups)
        if dimensions is not None:
            pulumi.set(__self__, "dimensions", dimensions)
        if effective_interval is not None:
            pulumi.set(__self__, "effective_interval", effective_interval)
        if email_subject is not None:
            pulumi.set(__self__, "email_subject", email_subject)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if no_effective_interval is not None:
            pulumi.set(__self__, "no_effective_interval", no_effective_interval)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if silence_time is not None:
            pulumi.set(__self__, "silence_time", silence_time)
        if targets is not None:
            pulumi.set(__self__, "targets", targets)
        if webhook is not None:
            pulumi.set(__self__, "webhook", webhook)

    @property
    @pulumi.getter
    def escalations(self) -> pulumi.Input['GroupMetricRuleEscalationsArgs']:
        """
        Alarm level. See `escalations` below.
        """
        return pulumi.get(self, "escalations")

    @escalations.setter
    def escalations(self, value: pulumi.Input['GroupMetricRuleEscalationsArgs']):
        pulumi.set(self, "escalations", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[str]:
        """
        The ID of the application group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="groupMetricRuleName")
    def group_metric_rule_name(self) -> pulumi.Input[str]:
        """
        The name of the alert rule.
        """
        return pulumi.get(self, "group_metric_rule_name")

    @group_metric_rule_name.setter
    def group_metric_rule_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_metric_rule_name", value)

    @property
    @pulumi.getter(name="metricName")
    def metric_name(self) -> pulumi.Input[str]:
        """
        The name of the metric.
        """
        return pulumi.get(self, "metric_name")

    @metric_name.setter
    def metric_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "metric_name", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        The namespace of the service.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Input[str]:
        """
        The ID of the alert rule.
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "rule_id", value)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[str]]:
        """
        The abbreviation of the service name.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter(name="contactGroups")
    def contact_groups(self) -> Optional[pulumi.Input[str]]:
        """
        Alarm contact group.
        """
        return pulumi.get(self, "contact_groups")

    @contact_groups.setter
    def contact_groups(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "contact_groups", value)

    @property
    @pulumi.getter
    def dimensions(self) -> Optional[pulumi.Input[str]]:
        """
        The dimensions that specify the resources to be associated with the alert rule.
        """
        return pulumi.get(self, "dimensions")

    @dimensions.setter
    def dimensions(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dimensions", value)

    @property
    @pulumi.getter(name="effectiveInterval")
    def effective_interval(self) -> Optional[pulumi.Input[str]]:
        """
        The time period during which the alert rule is effective.
        """
        return pulumi.get(self, "effective_interval")

    @effective_interval.setter
    def effective_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "effective_interval", value)

    @property
    @pulumi.getter(name="emailSubject")
    def email_subject(self) -> Optional[pulumi.Input[str]]:
        """
        The subject of the alert notification email.
        """
        return pulumi.get(self, "email_subject")

    @email_subject.setter
    def email_subject(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_subject", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[str]]:
        """
        The interval at which Cloud Monitor checks whether the alert rule is triggered. Unit: seconds.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter(name="noEffectiveInterval")
    def no_effective_interval(self) -> Optional[pulumi.Input[str]]:
        """
        The time period during which the alert rule is ineffective.
        """
        return pulumi.get(self, "no_effective_interval")

    @no_effective_interval.setter
    def no_effective_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "no_effective_interval", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The aggregation period of the monitoring data. Unit: seconds. The value is an integral multiple of 60. Default value: `300`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> Optional[pulumi.Input[int]]:
        """
        The mute period during which new alerts are not reported even if the alert trigger conditions are met. Unit: seconds. Default value: `86400`, which is equivalent to one day.
        """
        return pulumi.get(self, "silence_time")

    @silence_time.setter
    def silence_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "silence_time", value)

    @property
    @pulumi.getter
    def targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupMetricRuleTargetArgs']]]]:
        """
        The information about the resource for which alerts are triggered. See `targets` below.
        """
        return pulumi.get(self, "targets")

    @targets.setter
    def targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupMetricRuleTargetArgs']]]]):
        pulumi.set(self, "targets", value)

    @property
    @pulumi.getter
    def webhook(self) -> Optional[pulumi.Input[str]]:
        """
        The callback URL.
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "webhook", value)


@pulumi.input_type
class _GroupMetricRuleState:
    def __init__(__self__, *,
                 category: Optional[pulumi.Input[str]] = None,
                 contact_groups: Optional[pulumi.Input[str]] = None,
                 dimensions: Optional[pulumi.Input[str]] = None,
                 effective_interval: Optional[pulumi.Input[str]] = None,
                 email_subject: Optional[pulumi.Input[str]] = None,
                 escalations: Optional[pulumi.Input['GroupMetricRuleEscalationsArgs']] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 group_metric_rule_name: Optional[pulumi.Input[str]] = None,
                 interval: Optional[pulumi.Input[str]] = None,
                 metric_name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 no_effective_interval: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 rule_id: Optional[pulumi.Input[str]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input['GroupMetricRuleTargetArgs']]]] = None,
                 webhook: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering GroupMetricRule resources.
        :param pulumi.Input[str] category: The abbreviation of the service name.
        :param pulumi.Input[str] contact_groups: Alarm contact group.
        :param pulumi.Input[str] dimensions: The dimensions that specify the resources to be associated with the alert rule.
        :param pulumi.Input[str] effective_interval: The time period during which the alert rule is effective.
        :param pulumi.Input[str] email_subject: The subject of the alert notification email.
        :param pulumi.Input['GroupMetricRuleEscalationsArgs'] escalations: Alarm level. See `escalations` below.
        :param pulumi.Input[str] group_id: The ID of the application group.
        :param pulumi.Input[str] group_metric_rule_name: The name of the alert rule.
        :param pulumi.Input[str] interval: The interval at which Cloud Monitor checks whether the alert rule is triggered. Unit: seconds.
        :param pulumi.Input[str] metric_name: The name of the metric.
        :param pulumi.Input[str] namespace: The namespace of the service.
        :param pulumi.Input[str] no_effective_interval: The time period during which the alert rule is ineffective.
        :param pulumi.Input[int] period: The aggregation period of the monitoring data. Unit: seconds. The value is an integral multiple of 60. Default value: `300`.
        :param pulumi.Input[str] rule_id: The ID of the alert rule.
        :param pulumi.Input[int] silence_time: The mute period during which new alerts are not reported even if the alert trigger conditions are met. Unit: seconds. Default value: `86400`, which is equivalent to one day.
        :param pulumi.Input[str] status: The status of Group Metric Rule.
        :param pulumi.Input[Sequence[pulumi.Input['GroupMetricRuleTargetArgs']]] targets: The information about the resource for which alerts are triggered. See `targets` below.
        :param pulumi.Input[str] webhook: The callback URL.
        """
        if category is not None:
            pulumi.set(__self__, "category", category)
        if contact_groups is not None:
            pulumi.set(__self__, "contact_groups", contact_groups)
        if dimensions is not None:
            pulumi.set(__self__, "dimensions", dimensions)
        if effective_interval is not None:
            pulumi.set(__self__, "effective_interval", effective_interval)
        if email_subject is not None:
            pulumi.set(__self__, "email_subject", email_subject)
        if escalations is not None:
            pulumi.set(__self__, "escalations", escalations)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if group_metric_rule_name is not None:
            pulumi.set(__self__, "group_metric_rule_name", group_metric_rule_name)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if metric_name is not None:
            pulumi.set(__self__, "metric_name", metric_name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if no_effective_interval is not None:
            pulumi.set(__self__, "no_effective_interval", no_effective_interval)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)
        if silence_time is not None:
            pulumi.set(__self__, "silence_time", silence_time)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if targets is not None:
            pulumi.set(__self__, "targets", targets)
        if webhook is not None:
            pulumi.set(__self__, "webhook", webhook)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[str]]:
        """
        The abbreviation of the service name.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter(name="contactGroups")
    def contact_groups(self) -> Optional[pulumi.Input[str]]:
        """
        Alarm contact group.
        """
        return pulumi.get(self, "contact_groups")

    @contact_groups.setter
    def contact_groups(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "contact_groups", value)

    @property
    @pulumi.getter
    def dimensions(self) -> Optional[pulumi.Input[str]]:
        """
        The dimensions that specify the resources to be associated with the alert rule.
        """
        return pulumi.get(self, "dimensions")

    @dimensions.setter
    def dimensions(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dimensions", value)

    @property
    @pulumi.getter(name="effectiveInterval")
    def effective_interval(self) -> Optional[pulumi.Input[str]]:
        """
        The time period during which the alert rule is effective.
        """
        return pulumi.get(self, "effective_interval")

    @effective_interval.setter
    def effective_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "effective_interval", value)

    @property
    @pulumi.getter(name="emailSubject")
    def email_subject(self) -> Optional[pulumi.Input[str]]:
        """
        The subject of the alert notification email.
        """
        return pulumi.get(self, "email_subject")

    @email_subject.setter
    def email_subject(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_subject", value)

    @property
    @pulumi.getter
    def escalations(self) -> Optional[pulumi.Input['GroupMetricRuleEscalationsArgs']]:
        """
        Alarm level. See `escalations` below.
        """
        return pulumi.get(self, "escalations")

    @escalations.setter
    def escalations(self, value: Optional[pulumi.Input['GroupMetricRuleEscalationsArgs']]):
        pulumi.set(self, "escalations", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the application group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="groupMetricRuleName")
    def group_metric_rule_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the alert rule.
        """
        return pulumi.get(self, "group_metric_rule_name")

    @group_metric_rule_name.setter
    def group_metric_rule_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_metric_rule_name", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[str]]:
        """
        The interval at which Cloud Monitor checks whether the alert rule is triggered. Unit: seconds.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter(name="metricName")
    def metric_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the metric.
        """
        return pulumi.get(self, "metric_name")

    @metric_name.setter
    def metric_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "metric_name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace of the service.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="noEffectiveInterval")
    def no_effective_interval(self) -> Optional[pulumi.Input[str]]:
        """
        The time period during which the alert rule is ineffective.
        """
        return pulumi.get(self, "no_effective_interval")

    @no_effective_interval.setter
    def no_effective_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "no_effective_interval", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The aggregation period of the monitoring data. Unit: seconds. The value is an integral multiple of 60. Default value: `300`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the alert rule.
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_id", value)

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> Optional[pulumi.Input[int]]:
        """
        The mute period during which new alerts are not reported even if the alert trigger conditions are met. Unit: seconds. Default value: `86400`, which is equivalent to one day.
        """
        return pulumi.get(self, "silence_time")

    @silence_time.setter
    def silence_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "silence_time", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of Group Metric Rule.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupMetricRuleTargetArgs']]]]:
        """
        The information about the resource for which alerts are triggered. See `targets` below.
        """
        return pulumi.get(self, "targets")

    @targets.setter
    def targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupMetricRuleTargetArgs']]]]):
        pulumi.set(self, "targets", value)

    @property
    @pulumi.getter
    def webhook(self) -> Optional[pulumi.Input[str]]:
        """
        The callback URL.
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "webhook", value)


class GroupMetricRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 category: Optional[pulumi.Input[str]] = None,
                 contact_groups: Optional[pulumi.Input[str]] = None,
                 dimensions: Optional[pulumi.Input[str]] = None,
                 effective_interval: Optional[pulumi.Input[str]] = None,
                 email_subject: Optional[pulumi.Input[str]] = None,
                 escalations: Optional[pulumi.Input[Union['GroupMetricRuleEscalationsArgs', 'GroupMetricRuleEscalationsArgsDict']]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 group_metric_rule_name: Optional[pulumi.Input[str]] = None,
                 interval: Optional[pulumi.Input[str]] = None,
                 metric_name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 no_effective_interval: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 rule_id: Optional[pulumi.Input[str]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupMetricRuleTargetArgs', 'GroupMetricRuleTargetArgsDict']]]]] = None,
                 webhook: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloud Monitor Service Group Metric Rule resource.

        For information about Cloud Monitor Service Group Metric Rule and how to use it, see [What is Group Metric Rule](https://www.alibabacloud.com/help/en/cloudmonitor/latest/putgroupmetricrule).

        > **NOTE:** Available since v1.104.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.cms.AlarmContactGroup("default",
            alarm_contact_group_name=name,
            describe=name)
        default_monitor_group = alicloud.cms.MonitorGroup("default",
            monitor_group_name=name,
            contact_groups=[default.id])
        this = alicloud.cms.GroupMetricRule("this",
            group_id=default_monitor_group.id,
            group_metric_rule_name=name,
            category="ecs",
            metric_name="cpu_total",
            namespace="acs_ecs_dashboard",
            rule_id=name,
            period=60,
            interval="3600",
            silence_time=85800,
            no_effective_interval="00:00-05:30",
            webhook="http://www.aliyun.com",
            escalations={
                "warn": {
                    "comparison_operator": "GreaterThanOrEqualToThreshold",
                    "statistics": "Average",
                    "threshold": "90",
                    "times": 3,
                },
                "info": {
                    "comparison_operator": "LessThanLastWeek",
                    "statistics": "Average",
                    "threshold": "90",
                    "times": 5,
                },
            })
        ```

        ## Import

        Cloud Monitor Service Group Metric Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cms/groupMetricRule:GroupMetricRule example <rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] category: The abbreviation of the service name.
        :param pulumi.Input[str] contact_groups: Alarm contact group.
        :param pulumi.Input[str] dimensions: The dimensions that specify the resources to be associated with the alert rule.
        :param pulumi.Input[str] effective_interval: The time period during which the alert rule is effective.
        :param pulumi.Input[str] email_subject: The subject of the alert notification email.
        :param pulumi.Input[Union['GroupMetricRuleEscalationsArgs', 'GroupMetricRuleEscalationsArgsDict']] escalations: Alarm level. See `escalations` below.
        :param pulumi.Input[str] group_id: The ID of the application group.
        :param pulumi.Input[str] group_metric_rule_name: The name of the alert rule.
        :param pulumi.Input[str] interval: The interval at which Cloud Monitor checks whether the alert rule is triggered. Unit: seconds.
        :param pulumi.Input[str] metric_name: The name of the metric.
        :param pulumi.Input[str] namespace: The namespace of the service.
        :param pulumi.Input[str] no_effective_interval: The time period during which the alert rule is ineffective.
        :param pulumi.Input[int] period: The aggregation period of the monitoring data. Unit: seconds. The value is an integral multiple of 60. Default value: `300`.
        :param pulumi.Input[str] rule_id: The ID of the alert rule.
        :param pulumi.Input[int] silence_time: The mute period during which new alerts are not reported even if the alert trigger conditions are met. Unit: seconds. Default value: `86400`, which is equivalent to one day.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupMetricRuleTargetArgs', 'GroupMetricRuleTargetArgsDict']]]] targets: The information about the resource for which alerts are triggered. See `targets` below.
        :param pulumi.Input[str] webhook: The callback URL.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupMetricRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Monitor Service Group Metric Rule resource.

        For information about Cloud Monitor Service Group Metric Rule and how to use it, see [What is Group Metric Rule](https://www.alibabacloud.com/help/en/cloudmonitor/latest/putgroupmetricrule).

        > **NOTE:** Available since v1.104.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.cms.AlarmContactGroup("default",
            alarm_contact_group_name=name,
            describe=name)
        default_monitor_group = alicloud.cms.MonitorGroup("default",
            monitor_group_name=name,
            contact_groups=[default.id])
        this = alicloud.cms.GroupMetricRule("this",
            group_id=default_monitor_group.id,
            group_metric_rule_name=name,
            category="ecs",
            metric_name="cpu_total",
            namespace="acs_ecs_dashboard",
            rule_id=name,
            period=60,
            interval="3600",
            silence_time=85800,
            no_effective_interval="00:00-05:30",
            webhook="http://www.aliyun.com",
            escalations={
                "warn": {
                    "comparison_operator": "GreaterThanOrEqualToThreshold",
                    "statistics": "Average",
                    "threshold": "90",
                    "times": 3,
                },
                "info": {
                    "comparison_operator": "LessThanLastWeek",
                    "statistics": "Average",
                    "threshold": "90",
                    "times": 5,
                },
            })
        ```

        ## Import

        Cloud Monitor Service Group Metric Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cms/groupMetricRule:GroupMetricRule example <rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param GroupMetricRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupMetricRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 category: Optional[pulumi.Input[str]] = None,
                 contact_groups: Optional[pulumi.Input[str]] = None,
                 dimensions: Optional[pulumi.Input[str]] = None,
                 effective_interval: Optional[pulumi.Input[str]] = None,
                 email_subject: Optional[pulumi.Input[str]] = None,
                 escalations: Optional[pulumi.Input[Union['GroupMetricRuleEscalationsArgs', 'GroupMetricRuleEscalationsArgsDict']]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 group_metric_rule_name: Optional[pulumi.Input[str]] = None,
                 interval: Optional[pulumi.Input[str]] = None,
                 metric_name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 no_effective_interval: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 rule_id: Optional[pulumi.Input[str]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupMetricRuleTargetArgs', 'GroupMetricRuleTargetArgsDict']]]]] = None,
                 webhook: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupMetricRuleArgs.__new__(GroupMetricRuleArgs)

            __props__.__dict__["category"] = category
            __props__.__dict__["contact_groups"] = contact_groups
            __props__.__dict__["dimensions"] = dimensions
            __props__.__dict__["effective_interval"] = effective_interval
            __props__.__dict__["email_subject"] = email_subject
            if escalations is None and not opts.urn:
                raise TypeError("Missing required property 'escalations'")
            __props__.__dict__["escalations"] = escalations
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            if group_metric_rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'group_metric_rule_name'")
            __props__.__dict__["group_metric_rule_name"] = group_metric_rule_name
            __props__.__dict__["interval"] = interval
            if metric_name is None and not opts.urn:
                raise TypeError("Missing required property 'metric_name'")
            __props__.__dict__["metric_name"] = metric_name
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["no_effective_interval"] = no_effective_interval
            __props__.__dict__["period"] = period
            if rule_id is None and not opts.urn:
                raise TypeError("Missing required property 'rule_id'")
            __props__.__dict__["rule_id"] = rule_id
            __props__.__dict__["silence_time"] = silence_time
            __props__.__dict__["targets"] = targets
            __props__.__dict__["webhook"] = webhook
            __props__.__dict__["status"] = None
        super(GroupMetricRule, __self__).__init__(
            'alicloud:cms/groupMetricRule:GroupMetricRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            category: Optional[pulumi.Input[str]] = None,
            contact_groups: Optional[pulumi.Input[str]] = None,
            dimensions: Optional[pulumi.Input[str]] = None,
            effective_interval: Optional[pulumi.Input[str]] = None,
            email_subject: Optional[pulumi.Input[str]] = None,
            escalations: Optional[pulumi.Input[Union['GroupMetricRuleEscalationsArgs', 'GroupMetricRuleEscalationsArgsDict']]] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            group_metric_rule_name: Optional[pulumi.Input[str]] = None,
            interval: Optional[pulumi.Input[str]] = None,
            metric_name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            no_effective_interval: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            rule_id: Optional[pulumi.Input[str]] = None,
            silence_time: Optional[pulumi.Input[int]] = None,
            status: Optional[pulumi.Input[str]] = None,
            targets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupMetricRuleTargetArgs', 'GroupMetricRuleTargetArgsDict']]]]] = None,
            webhook: Optional[pulumi.Input[str]] = None) -> 'GroupMetricRule':
        """
        Get an existing GroupMetricRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] category: The abbreviation of the service name.
        :param pulumi.Input[str] contact_groups: Alarm contact group.
        :param pulumi.Input[str] dimensions: The dimensions that specify the resources to be associated with the alert rule.
        :param pulumi.Input[str] effective_interval: The time period during which the alert rule is effective.
        :param pulumi.Input[str] email_subject: The subject of the alert notification email.
        :param pulumi.Input[Union['GroupMetricRuleEscalationsArgs', 'GroupMetricRuleEscalationsArgsDict']] escalations: Alarm level. See `escalations` below.
        :param pulumi.Input[str] group_id: The ID of the application group.
        :param pulumi.Input[str] group_metric_rule_name: The name of the alert rule.
        :param pulumi.Input[str] interval: The interval at which Cloud Monitor checks whether the alert rule is triggered. Unit: seconds.
        :param pulumi.Input[str] metric_name: The name of the metric.
        :param pulumi.Input[str] namespace: The namespace of the service.
        :param pulumi.Input[str] no_effective_interval: The time period during which the alert rule is ineffective.
        :param pulumi.Input[int] period: The aggregation period of the monitoring data. Unit: seconds. The value is an integral multiple of 60. Default value: `300`.
        :param pulumi.Input[str] rule_id: The ID of the alert rule.
        :param pulumi.Input[int] silence_time: The mute period during which new alerts are not reported even if the alert trigger conditions are met. Unit: seconds. Default value: `86400`, which is equivalent to one day.
        :param pulumi.Input[str] status: The status of Group Metric Rule.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupMetricRuleTargetArgs', 'GroupMetricRuleTargetArgsDict']]]] targets: The information about the resource for which alerts are triggered. See `targets` below.
        :param pulumi.Input[str] webhook: The callback URL.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupMetricRuleState.__new__(_GroupMetricRuleState)

        __props__.__dict__["category"] = category
        __props__.__dict__["contact_groups"] = contact_groups
        __props__.__dict__["dimensions"] = dimensions
        __props__.__dict__["effective_interval"] = effective_interval
        __props__.__dict__["email_subject"] = email_subject
        __props__.__dict__["escalations"] = escalations
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["group_metric_rule_name"] = group_metric_rule_name
        __props__.__dict__["interval"] = interval
        __props__.__dict__["metric_name"] = metric_name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["no_effective_interval"] = no_effective_interval
        __props__.__dict__["period"] = period
        __props__.__dict__["rule_id"] = rule_id
        __props__.__dict__["silence_time"] = silence_time
        __props__.__dict__["status"] = status
        __props__.__dict__["targets"] = targets
        __props__.__dict__["webhook"] = webhook
        return GroupMetricRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def category(self) -> pulumi.Output[Optional[str]]:
        """
        The abbreviation of the service name.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="contactGroups")
    def contact_groups(self) -> pulumi.Output[str]:
        """
        Alarm contact group.
        """
        return pulumi.get(self, "contact_groups")

    @property
    @pulumi.getter
    def dimensions(self) -> pulumi.Output[str]:
        """
        The dimensions that specify the resources to be associated with the alert rule.
        """
        return pulumi.get(self, "dimensions")

    @property
    @pulumi.getter(name="effectiveInterval")
    def effective_interval(self) -> pulumi.Output[Optional[str]]:
        """
        The time period during which the alert rule is effective.
        """
        return pulumi.get(self, "effective_interval")

    @property
    @pulumi.getter(name="emailSubject")
    def email_subject(self) -> pulumi.Output[str]:
        """
        The subject of the alert notification email.
        """
        return pulumi.get(self, "email_subject")

    @property
    @pulumi.getter
    def escalations(self) -> pulumi.Output['outputs.GroupMetricRuleEscalations']:
        """
        Alarm level. See `escalations` below.
        """
        return pulumi.get(self, "escalations")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        The ID of the application group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupMetricRuleName")
    def group_metric_rule_name(self) -> pulumi.Output[str]:
        """
        The name of the alert rule.
        """
        return pulumi.get(self, "group_metric_rule_name")

    @property
    @pulumi.getter
    def interval(self) -> pulumi.Output[Optional[str]]:
        """
        The interval at which Cloud Monitor checks whether the alert rule is triggered. Unit: seconds.
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="metricName")
    def metric_name(self) -> pulumi.Output[str]:
        """
        The name of the metric.
        """
        return pulumi.get(self, "metric_name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[str]:
        """
        The namespace of the service.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="noEffectiveInterval")
    def no_effective_interval(self) -> pulumi.Output[Optional[str]]:
        """
        The time period during which the alert rule is ineffective.
        """
        return pulumi.get(self, "no_effective_interval")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[int]:
        """
        The aggregation period of the monitoring data. Unit: seconds. The value is an integral multiple of 60. Default value: `300`.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[str]:
        """
        The ID of the alert rule.
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> pulumi.Output[int]:
        """
        The mute period during which new alerts are not reported even if the alert trigger conditions are met. Unit: seconds. Default value: `86400`, which is equivalent to one day.
        """
        return pulumi.get(self, "silence_time")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of Group Metric Rule.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def targets(self) -> pulumi.Output[Sequence['outputs.GroupMetricRuleTarget']]:
        """
        The information about the resource for which alerts are triggered. See `targets` below.
        """
        return pulumi.get(self, "targets")

    @property
    @pulumi.getter
    def webhook(self) -> pulumi.Output[Optional[str]]:
        """
        The callback URL.
        """
        return pulumi.get(self, "webhook")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPublicIpAddressPoolCidrBlocksResult',
    'AwaitableGetPublicIpAddressPoolCidrBlocksResult',
    'get_public_ip_address_pool_cidr_blocks',
    'get_public_ip_address_pool_cidr_blocks_output',
]

@pulumi.output_type
class GetPublicIpAddressPoolCidrBlocksResult:
    """
    A collection of values returned by getPublicIpAddressPoolCidrBlocks.
    """
    def __init__(__self__, blocks=None, cidr_block=None, id=None, ids=None, output_file=None, public_ip_address_pool_id=None, status=None):
        if blocks and not isinstance(blocks, list):
            raise TypeError("Expected argument 'blocks' to be a list")
        pulumi.set(__self__, "blocks", blocks)
        if cidr_block and not isinstance(cidr_block, str):
            raise TypeError("Expected argument 'cidr_block' to be a str")
        pulumi.set(__self__, "cidr_block", cidr_block)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if public_ip_address_pool_id and not isinstance(public_ip_address_pool_id, str):
            raise TypeError("Expected argument 'public_ip_address_pool_id' to be a str")
        pulumi.set(__self__, "public_ip_address_pool_id", public_ip_address_pool_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def blocks(self) -> Sequence['outputs.GetPublicIpAddressPoolCidrBlocksBlockResult']:
        """
        A list of Vpc Public Ip Address Pool Cidr Blocks. Each element contains the following attributes:
        """
        return pulumi.get(self, "blocks")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> Optional[str]:
        """
        The CIDR block.
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="publicIpAddressPoolId")
    def public_ip_address_pool_id(self) -> str:
        """
        The ID of the Vpc Public IP address pool.
        """
        return pulumi.get(self, "public_ip_address_pool_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the CIDR block in the Vpc Public IP address pool.
        """
        return pulumi.get(self, "status")


class AwaitableGetPublicIpAddressPoolCidrBlocksResult(GetPublicIpAddressPoolCidrBlocksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPublicIpAddressPoolCidrBlocksResult(
            blocks=self.blocks,
            cidr_block=self.cidr_block,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            public_ip_address_pool_id=self.public_ip_address_pool_id,
            status=self.status)


def get_public_ip_address_pool_cidr_blocks(cidr_block: Optional[str] = None,
                                           ids: Optional[Sequence[str]] = None,
                                           output_file: Optional[str] = None,
                                           public_ip_address_pool_id: Optional[str] = None,
                                           status: Optional[str] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPublicIpAddressPoolCidrBlocksResult:
    """
    This data source provides the Vpc Public Ip Address Pool Cidr Blocks of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.189.0+.

    > **NOTE:** Only users who have the required permissions can use the IP address pool feature of Elastic IP Address (EIP). To apply for the required permissions, [submit a ticket](https://smartservice.console.aliyun.com/service/create-ticket).

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_public_ip_address_pool_cidr_blocks(ids=["example_id"],
        public_ip_address_pool_id="example_value")
    pulumi.export("vpcPublicIpAddressPoolCidrBlockId1", ids.blocks[0].id)
    cidr_block = alicloud.vpc.get_public_ip_address_pool_cidr_blocks(public_ip_address_pool_id="example_value",
        cidr_block="example_value")
    pulumi.export("vpcPublicIpAddressPoolCidrBlockId2", cidr_block.blocks[0].id)
    ```


    :param str cidr_block: The CIDR block.
    :param Sequence[str] ids: A list of Vpc Public Ip Address Pool Cidr Block IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str public_ip_address_pool_id: The ID of the Vpc Public IP address pool.
    :param str status: The status of the CIDR block in the Vpc Public IP address pool. Valid values: `Created`, `Modifying`, `Deleting`.
    """
    __args__ = dict()
    __args__['cidrBlock'] = cidr_block
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['publicIpAddressPoolId'] = public_ip_address_pool_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getPublicIpAddressPoolCidrBlocks:getPublicIpAddressPoolCidrBlocks', __args__, opts=opts, typ=GetPublicIpAddressPoolCidrBlocksResult).value

    return AwaitableGetPublicIpAddressPoolCidrBlocksResult(
        blocks=pulumi.get(__ret__, 'blocks'),
        cidr_block=pulumi.get(__ret__, 'cidr_block'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        public_ip_address_pool_id=pulumi.get(__ret__, 'public_ip_address_pool_id'),
        status=pulumi.get(__ret__, 'status'))
def get_public_ip_address_pool_cidr_blocks_output(cidr_block: Optional[pulumi.Input[Optional[str]]] = None,
                                                  ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                                  output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                  public_ip_address_pool_id: Optional[pulumi.Input[str]] = None,
                                                  status: Optional[pulumi.Input[Optional[str]]] = None,
                                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPublicIpAddressPoolCidrBlocksResult]:
    """
    This data source provides the Vpc Public Ip Address Pool Cidr Blocks of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.189.0+.

    > **NOTE:** Only users who have the required permissions can use the IP address pool feature of Elastic IP Address (EIP). To apply for the required permissions, [submit a ticket](https://smartservice.console.aliyun.com/service/create-ticket).

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_public_ip_address_pool_cidr_blocks(ids=["example_id"],
        public_ip_address_pool_id="example_value")
    pulumi.export("vpcPublicIpAddressPoolCidrBlockId1", ids.blocks[0].id)
    cidr_block = alicloud.vpc.get_public_ip_address_pool_cidr_blocks(public_ip_address_pool_id="example_value",
        cidr_block="example_value")
    pulumi.export("vpcPublicIpAddressPoolCidrBlockId2", cidr_block.blocks[0].id)
    ```


    :param str cidr_block: The CIDR block.
    :param Sequence[str] ids: A list of Vpc Public Ip Address Pool Cidr Block IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str public_ip_address_pool_id: The ID of the Vpc Public IP address pool.
    :param str status: The status of the CIDR block in the Vpc Public IP address pool. Valid values: `Created`, `Modifying`, `Deleting`.
    """
    __args__ = dict()
    __args__['cidrBlock'] = cidr_block
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['publicIpAddressPoolId'] = public_ip_address_pool_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getPublicIpAddressPoolCidrBlocks:getPublicIpAddressPoolCidrBlocks', __args__, opts=opts, typ=GetPublicIpAddressPoolCidrBlocksResult)
    return __ret__.apply(lambda __response__: GetPublicIpAddressPoolCidrBlocksResult(
        blocks=pulumi.get(__response__, 'blocks'),
        cidr_block=pulumi.get(__response__, 'cidr_block'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        public_ip_address_pool_id=pulumi.get(__response__, 'public_ip_address_pool_id'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTransitRouterMulticastDomainsResult',
    'AwaitableGetTransitRouterMulticastDomainsResult',
    'get_transit_router_multicast_domains',
    'get_transit_router_multicast_domains_output',
]

@pulumi.output_type
class GetTransitRouterMulticastDomainsResult:
    """
    A collection of values returned by getTransitRouterMulticastDomains.
    """
    def __init__(__self__, domains=None, id=None, ids=None, name_regex=None, names=None, output_file=None, status=None, transit_router_id=None, transit_router_multicast_domain_id=None):
        if domains and not isinstance(domains, list):
            raise TypeError("Expected argument 'domains' to be a list")
        pulumi.set(__self__, "domains", domains)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if transit_router_id and not isinstance(transit_router_id, str):
            raise TypeError("Expected argument 'transit_router_id' to be a str")
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_multicast_domain_id and not isinstance(transit_router_multicast_domain_id, str):
            raise TypeError("Expected argument 'transit_router_multicast_domain_id' to be a str")
        pulumi.set(__self__, "transit_router_multicast_domain_id", transit_router_multicast_domain_id)

    @property
    @pulumi.getter
    def domains(self) -> Sequence['outputs.GetTransitRouterMulticastDomainsDomainResult']:
        """
        A list of Cen Transit Router Multicast Domains. Each element contains the following attributes:
        """
        return pulumi.get(self, "domains")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Transit Router Multicast Domain names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the Transit Router Multicast Domain.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> str:
        """
        The ID of the transit router.
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterMulticastDomainId")
    def transit_router_multicast_domain_id(self) -> Optional[str]:
        """
        The ID of the Transit Router Multicast Domain.
        """
        return pulumi.get(self, "transit_router_multicast_domain_id")


class AwaitableGetTransitRouterMulticastDomainsResult(GetTransitRouterMulticastDomainsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTransitRouterMulticastDomainsResult(
            domains=self.domains,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status,
            transit_router_id=self.transit_router_id,
            transit_router_multicast_domain_id=self.transit_router_multicast_domain_id)


def get_transit_router_multicast_domains(ids: Optional[Sequence[str]] = None,
                                         name_regex: Optional[str] = None,
                                         output_file: Optional[str] = None,
                                         status: Optional[str] = None,
                                         transit_router_id: Optional[str] = None,
                                         transit_router_multicast_domain_id: Optional[str] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTransitRouterMulticastDomainsResult:
    """
    This data source provides the Cen Transit Router Multicast Domains of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.195.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cen.get_transit_router_multicast_domains(ids=["example_id"],
        transit_router_id="your_transit_router_id")
    pulumi.export("cenTransitRouterMulticastDomainId0", ids.domains[0].id)
    name_regex = alicloud.cen.get_transit_router_multicast_domains(name_regex="^my-name",
        transit_router_id="your_transit_router_id")
    pulumi.export("cenTransitRouterMulticastDomainId1", name_regex.domains[0].id)
    ```


    :param Sequence[str] ids: A list of Transit Router Multicast Domain IDs.
    :param str name_regex: A regex string to filter results by Transit Router Multicast Domain name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the multicast domain. Valid Value: `Active`.
    :param str transit_router_id: The ID of the transit router.
    :param str transit_router_multicast_domain_id: The ID of the multicast domain.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['transitRouterId'] = transit_router_id
    __args__['transitRouterMulticastDomainId'] = transit_router_multicast_domain_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getTransitRouterMulticastDomains:getTransitRouterMulticastDomains', __args__, opts=opts, typ=GetTransitRouterMulticastDomainsResult).value

    return AwaitableGetTransitRouterMulticastDomainsResult(
        domains=pulumi.get(__ret__, 'domains'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'),
        transit_router_id=pulumi.get(__ret__, 'transit_router_id'),
        transit_router_multicast_domain_id=pulumi.get(__ret__, 'transit_router_multicast_domain_id'))
def get_transit_router_multicast_domains_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                                name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                                output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                status: Optional[pulumi.Input[Optional[str]]] = None,
                                                transit_router_id: Optional[pulumi.Input[str]] = None,
                                                transit_router_multicast_domain_id: Optional[pulumi.Input[Optional[str]]] = None,
                                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTransitRouterMulticastDomainsResult]:
    """
    This data source provides the Cen Transit Router Multicast Domains of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.195.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cen.get_transit_router_multicast_domains(ids=["example_id"],
        transit_router_id="your_transit_router_id")
    pulumi.export("cenTransitRouterMulticastDomainId0", ids.domains[0].id)
    name_regex = alicloud.cen.get_transit_router_multicast_domains(name_regex="^my-name",
        transit_router_id="your_transit_router_id")
    pulumi.export("cenTransitRouterMulticastDomainId1", name_regex.domains[0].id)
    ```


    :param Sequence[str] ids: A list of Transit Router Multicast Domain IDs.
    :param str name_regex: A regex string to filter results by Transit Router Multicast Domain name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the multicast domain. Valid Value: `Active`.
    :param str transit_router_id: The ID of the transit router.
    :param str transit_router_multicast_domain_id: The ID of the multicast domain.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['transitRouterId'] = transit_router_id
    __args__['transitRouterMulticastDomainId'] = transit_router_multicast_domain_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cen/getTransitRouterMulticastDomains:getTransitRouterMulticastDomains', __args__, opts=opts, typ=GetTransitRouterMulticastDomainsResult)
    return __ret__.apply(lambda __response__: GetTransitRouterMulticastDomainsResult(
        domains=pulumi.get(__response__, 'domains'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        status=pulumi.get(__response__, 'status'),
        transit_router_id=pulumi.get(__response__, 'transit_router_id'),
        transit_router_multicast_domain_id=pulumi.get(__response__, 'transit_router_multicast_domain_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 project_name: pulumi.Input[str],
                 project_mode: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[str] description: Description of the workspace
        :param pulumi.Input[str] display_name: The display name of the workspace.
        :param pulumi.Input[str] project_name: Immutable Name of the workspace.
        :param pulumi.Input[int] project_mode: The mode of the workspace, with the following values:
               - 2, indicates the simple workspace mode.
               - 3, indicating the standard workspace mode.
        :param pulumi.Input[str] status: The status of the resource
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "project_name", project_name)
        if project_mode is not None:
            pulumi.set(__self__, "project_mode", project_mode)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[str]:
        """
        Description of the workspace
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        The display name of the workspace.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[str]:
        """
        Immutable Name of the workspace.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="projectMode")
    def project_mode(self) -> Optional[pulumi.Input[int]]:
        """
        The mode of the workspace, with the following values:
        - 2, indicates the simple workspace mode.
        - 3, indicating the standard workspace mode.
        """
        return pulumi.get(self, "project_mode")

    @project_mode.setter
    def project_mode(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "project_mode", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 project_mode: Optional[pulumi.Input[int]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] description: Description of the workspace
        :param pulumi.Input[str] display_name: The display name of the workspace.
        :param pulumi.Input[int] project_mode: The mode of the workspace, with the following values:
               - 2, indicates the simple workspace mode.
               - 3, indicating the standard workspace mode.
        :param pulumi.Input[str] project_name: Immutable Name of the workspace.
        :param pulumi.Input[str] status: The status of the resource
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if project_mode is not None:
            pulumi.set(__self__, "project_mode", project_mode)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the workspace
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The display name of the workspace.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="projectMode")
    def project_mode(self) -> Optional[pulumi.Input[int]]:
        """
        The mode of the workspace, with the following values:
        - 2, indicates the simple workspace mode.
        - 3, indicating the standard workspace mode.
        """
        return pulumi.get(self, "project_mode")

    @project_mode.setter
    def project_mode(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "project_mode", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        Immutable Name of the workspace.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 project_mode: Optional[pulumi.Input[int]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Data Works Project resource.

        For information about Data Works Project and how to use it, see [What is Project](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2020-05-18-createproject).

        > **NOTE:** Available since v1.229.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_project = alicloud.dataworks.Project("default",
            project_name=f"{name}_{default['result']}",
            project_mode=2,
            description=f"{name}_{default['result']}",
            display_name=f"{name}_{default['result']}",
            status="0")
        ```

        ## Import

        Data Works Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/project:Project example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the workspace
        :param pulumi.Input[str] display_name: The display name of the workspace.
        :param pulumi.Input[int] project_mode: The mode of the workspace, with the following values:
               - 2, indicates the simple workspace mode.
               - 3, indicating the standard workspace mode.
        :param pulumi.Input[str] project_name: Immutable Name of the workspace.
        :param pulumi.Input[str] status: The status of the resource
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Project resource.

        For information about Data Works Project and how to use it, see [What is Project](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2020-05-18-createproject).

        > **NOTE:** Available since v1.229.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_project = alicloud.dataworks.Project("default",
            project_name=f"{name}_{default['result']}",
            project_mode=2,
            description=f"{name}_{default['result']}",
            display_name=f"{name}_{default['result']}",
            status="0")
        ```

        ## Import

        Data Works Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/project:Project example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 project_mode: Optional[pulumi.Input[int]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["project_mode"] = project_mode
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["status"] = status
            __props__.__dict__["create_time"] = None
        super(Project, __self__).__init__(
            'alicloud:dataworks/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            project_mode: Optional[pulumi.Input[int]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] description: Description of the workspace
        :param pulumi.Input[str] display_name: The display name of the workspace.
        :param pulumi.Input[int] project_mode: The mode of the workspace, with the following values:
               - 2, indicates the simple workspace mode.
               - 3, indicating the standard workspace mode.
        :param pulumi.Input[str] project_name: Immutable Name of the workspace.
        :param pulumi.Input[str] status: The status of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["project_mode"] = project_mode
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        return Project(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the workspace
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        The display name of the workspace.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="projectMode")
    def project_mode(self) -> pulumi.Output[Optional[int]]:
        """
        The mode of the workspace, with the following values:
        - 2, indicates the simple workspace mode.
        - 3, indicating the standard workspace mode.
        """
        return pulumi.get(self, "project_mode")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        Immutable Name of the workspace.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LoadBalancerIntranetArgs', 'LoadBalancerIntranet']

@pulumi.input_type
class LoadBalancerIntranetArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[str],
                 intranets: pulumi.Input[Sequence[pulumi.Input['LoadBalancerIntranetIntranetArgs']]],
                 intranet_slb_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a LoadBalancerIntranet resource.
        :param pulumi.Input[str] app_id: The target application ID that needs to be bound to the SLB.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerIntranetIntranetArgs']]] intranets: The bound private network SLB. See `intranet` below.
        :param pulumi.Input[str] intranet_slb_id: The intranet SLB ID.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "intranets", intranets)
        if intranet_slb_id is not None:
            pulumi.set(__self__, "intranet_slb_id", intranet_slb_id)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[str]:
        """
        The target application ID that needs to be bound to the SLB.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter
    def intranets(self) -> pulumi.Input[Sequence[pulumi.Input['LoadBalancerIntranetIntranetArgs']]]:
        """
        The bound private network SLB. See `intranet` below.
        """
        return pulumi.get(self, "intranets")

    @intranets.setter
    def intranets(self, value: pulumi.Input[Sequence[pulumi.Input['LoadBalancerIntranetIntranetArgs']]]):
        pulumi.set(self, "intranets", value)

    @property
    @pulumi.getter(name="intranetSlbId")
    def intranet_slb_id(self) -> Optional[pulumi.Input[str]]:
        """
        The intranet SLB ID.
        """
        return pulumi.get(self, "intranet_slb_id")

    @intranet_slb_id.setter
    def intranet_slb_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "intranet_slb_id", value)


@pulumi.input_type
class _LoadBalancerIntranetState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[str]] = None,
                 intranet_ip: Optional[pulumi.Input[str]] = None,
                 intranet_slb_id: Optional[pulumi.Input[str]] = None,
                 intranets: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerIntranetIntranetArgs']]]] = None):
        """
        Input properties used for looking up and filtering LoadBalancerIntranet resources.
        :param pulumi.Input[str] app_id: The target application ID that needs to be bound to the SLB.
        :param pulumi.Input[str] intranet_ip: Use designated private network SLBs that have been purchased to support non-shared instances.
        :param pulumi.Input[str] intranet_slb_id: The intranet SLB ID.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerIntranetIntranetArgs']]] intranets: The bound private network SLB. See `intranet` below.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if intranet_ip is not None:
            pulumi.set(__self__, "intranet_ip", intranet_ip)
        if intranet_slb_id is not None:
            pulumi.set(__self__, "intranet_slb_id", intranet_slb_id)
        if intranets is not None:
            pulumi.set(__self__, "intranets", intranets)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[str]]:
        """
        The target application ID that needs to be bound to the SLB.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="intranetIp")
    def intranet_ip(self) -> Optional[pulumi.Input[str]]:
        """
        Use designated private network SLBs that have been purchased to support non-shared instances.
        """
        return pulumi.get(self, "intranet_ip")

    @intranet_ip.setter
    def intranet_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "intranet_ip", value)

    @property
    @pulumi.getter(name="intranetSlbId")
    def intranet_slb_id(self) -> Optional[pulumi.Input[str]]:
        """
        The intranet SLB ID.
        """
        return pulumi.get(self, "intranet_slb_id")

    @intranet_slb_id.setter
    def intranet_slb_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "intranet_slb_id", value)

    @property
    @pulumi.getter
    def intranets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerIntranetIntranetArgs']]]]:
        """
        The bound private network SLB. See `intranet` below.
        """
        return pulumi.get(self, "intranets")

    @intranets.setter
    def intranets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerIntranetIntranetArgs']]]]):
        pulumi.set(self, "intranets", value)


class LoadBalancerIntranet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[str]] = None,
                 intranet_slb_id: Optional[pulumi.Input[str]] = None,
                 intranets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerIntranetIntranetArgs', 'LoadBalancerIntranetIntranetArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides an Alicloud Serverless App Engine (SAE) Application Load Balancer Attachment resource.

        For information about Serverless App Engine (SAE) Load Balancer Intranet Attachment and how to use it, see [sae.LoadBalancerIntranet](https://www.alibabacloud.com/help/en/sae/latest/bindslb).

        > **NOTE:** Available since v1.165.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.get_regions(current=True)
        default_integer = random.index.Integer("default",
            max=99999,
            min=10000)
        default_get_zones = alicloud.get_zones(available_resource_creation="VSwitch")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            cidr_block="10.4.0.0/24",
            vpc_id=default_network.id,
            zone_id=default_get_zones.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("default", vpc_id=default_network.id)
        default_namespace = alicloud.sae.Namespace("default",
            namespace_id=f"{default.regions[0].id}:example{default_integer['result']}",
            namespace_name=name,
            namespace_description=name,
            enable_micro_registration=False)
        default_application = alicloud.sae.Application("default",
            app_description=name,
            app_name=f"{name}-{default_integer['result']}",
            namespace_id=default_namespace.id,
            image_url="registry-vpc.cn-hangzhou.aliyuncs.com/lxepoo/apache-php5",
            package_type="Image",
            jdk="Open JDK 8",
            security_group_id=default_security_group.id,
            vpc_id=default_network.id,
            vswitch_id=default_switch.id,
            timezone="Asia/Beijing",
            replicas=5,
            cpu=500,
            memory=2048,
            micro_registration="0")
        default_application_load_balancer = alicloud.slb.ApplicationLoadBalancer("default",
            load_balancer_name=name,
            vswitch_id=default_switch.id,
            load_balancer_spec="slb.s2.small",
            address_type="intranet")
        default_load_balancer_intranet = alicloud.sae.LoadBalancerIntranet("default",
            app_id=default_application.id,
            intranet_slb_id=default_application_load_balancer.id,
            intranets=[{
                "protocol": "TCP",
                "port": 80,
                "target_port": 8080,
            }])
        ```

        ## Import

        The resource can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sae/loadBalancerIntranet:LoadBalancerIntranet example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_id: The target application ID that needs to be bound to the SLB.
        :param pulumi.Input[str] intranet_slb_id: The intranet SLB ID.
        :param pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerIntranetIntranetArgs', 'LoadBalancerIntranetIntranetArgsDict']]]] intranets: The bound private network SLB. See `intranet` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LoadBalancerIntranetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an Alicloud Serverless App Engine (SAE) Application Load Balancer Attachment resource.

        For information about Serverless App Engine (SAE) Load Balancer Intranet Attachment and how to use it, see [sae.LoadBalancerIntranet](https://www.alibabacloud.com/help/en/sae/latest/bindslb).

        > **NOTE:** Available since v1.165.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.get_regions(current=True)
        default_integer = random.index.Integer("default",
            max=99999,
            min=10000)
        default_get_zones = alicloud.get_zones(available_resource_creation="VSwitch")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            cidr_block="10.4.0.0/24",
            vpc_id=default_network.id,
            zone_id=default_get_zones.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("default", vpc_id=default_network.id)
        default_namespace = alicloud.sae.Namespace("default",
            namespace_id=f"{default.regions[0].id}:example{default_integer['result']}",
            namespace_name=name,
            namespace_description=name,
            enable_micro_registration=False)
        default_application = alicloud.sae.Application("default",
            app_description=name,
            app_name=f"{name}-{default_integer['result']}",
            namespace_id=default_namespace.id,
            image_url="registry-vpc.cn-hangzhou.aliyuncs.com/lxepoo/apache-php5",
            package_type="Image",
            jdk="Open JDK 8",
            security_group_id=default_security_group.id,
            vpc_id=default_network.id,
            vswitch_id=default_switch.id,
            timezone="Asia/Beijing",
            replicas=5,
            cpu=500,
            memory=2048,
            micro_registration="0")
        default_application_load_balancer = alicloud.slb.ApplicationLoadBalancer("default",
            load_balancer_name=name,
            vswitch_id=default_switch.id,
            load_balancer_spec="slb.s2.small",
            address_type="intranet")
        default_load_balancer_intranet = alicloud.sae.LoadBalancerIntranet("default",
            app_id=default_application.id,
            intranet_slb_id=default_application_load_balancer.id,
            intranets=[{
                "protocol": "TCP",
                "port": 80,
                "target_port": 8080,
            }])
        ```

        ## Import

        The resource can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sae/loadBalancerIntranet:LoadBalancerIntranet example <id>
        ```

        :param str resource_name: The name of the resource.
        :param LoadBalancerIntranetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoadBalancerIntranetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[str]] = None,
                 intranet_slb_id: Optional[pulumi.Input[str]] = None,
                 intranets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerIntranetIntranetArgs', 'LoadBalancerIntranetIntranetArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoadBalancerIntranetArgs.__new__(LoadBalancerIntranetArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["intranet_slb_id"] = intranet_slb_id
            if intranets is None and not opts.urn:
                raise TypeError("Missing required property 'intranets'")
            __props__.__dict__["intranets"] = intranets
            __props__.__dict__["intranet_ip"] = None
        super(LoadBalancerIntranet, __self__).__init__(
            'alicloud:sae/loadBalancerIntranet:LoadBalancerIntranet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[str]] = None,
            intranet_ip: Optional[pulumi.Input[str]] = None,
            intranet_slb_id: Optional[pulumi.Input[str]] = None,
            intranets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerIntranetIntranetArgs', 'LoadBalancerIntranetIntranetArgsDict']]]]] = None) -> 'LoadBalancerIntranet':
        """
        Get an existing LoadBalancerIntranet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_id: The target application ID that needs to be bound to the SLB.
        :param pulumi.Input[str] intranet_ip: Use designated private network SLBs that have been purchased to support non-shared instances.
        :param pulumi.Input[str] intranet_slb_id: The intranet SLB ID.
        :param pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerIntranetIntranetArgs', 'LoadBalancerIntranetIntranetArgsDict']]]] intranets: The bound private network SLB. See `intranet` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoadBalancerIntranetState.__new__(_LoadBalancerIntranetState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["intranet_ip"] = intranet_ip
        __props__.__dict__["intranet_slb_id"] = intranet_slb_id
        __props__.__dict__["intranets"] = intranets
        return LoadBalancerIntranet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[str]:
        """
        The target application ID that needs to be bound to the SLB.
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter(name="intranetIp")
    def intranet_ip(self) -> pulumi.Output[str]:
        """
        Use designated private network SLBs that have been purchased to support non-shared instances.
        """
        return pulumi.get(self, "intranet_ip")

    @property
    @pulumi.getter(name="intranetSlbId")
    def intranet_slb_id(self) -> pulumi.Output[Optional[str]]:
        """
        The intranet SLB ID.
        """
        return pulumi.get(self, "intranet_slb_id")

    @property
    @pulumi.getter
    def intranets(self) -> pulumi.Output[Sequence['outputs.LoadBalancerIntranetIntranet']]:
        """
        The bound private network SLB. See `intranet` below.
        """
        return pulumi.get(self, "intranets")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NatFirewallArgs', 'NatFirewall']

@pulumi.input_type
class NatFirewallArgs:
    def __init__(__self__, *,
                 nat_gateway_id: pulumi.Input[str],
                 nat_route_entry_lists: pulumi.Input[Sequence[pulumi.Input['NatFirewallNatRouteEntryListArgs']]],
                 proxy_name: pulumi.Input[str],
                 region_no: pulumi.Input[str],
                 vpc_id: pulumi.Input[str],
                 firewall_switch: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 strict_mode: Optional[pulumi.Input[int]] = None,
                 vswitch_auto: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NatFirewall resource.
        :param pulumi.Input[str] nat_gateway_id: NAT gateway ID.
        :param pulumi.Input[Sequence[pulumi.Input['NatFirewallNatRouteEntryListArgs']]] nat_route_entry_lists: The list of routes to be switched by the NAT gateway. See `nat_route_entry_list` below.
        :param pulumi.Input[str] proxy_name: NAT firewall name.
        :param pulumi.Input[str] region_no: Region.
        :param pulumi.Input[str] vpc_id: The ID of the VPC instance.
        :param pulumi.Input[str] firewall_switch: Safety protection switch. Value:-**open**: open-**close**: close.
        :param pulumi.Input[str] lang: Lang.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[int] strict_mode: Whether strict mode is enabled 1-Enable strict mode 0-Disable strict mode.
        :param pulumi.Input[str] vswitch_auto: Whether to use switch automatic mode. Value: **true**: Use automatic mode: **false**: Use manual mode.
        :param pulumi.Input[str] vswitch_cidr: The network segment of the virtual switch. Required for Switch automatic mode.
        :param pulumi.Input[str] vswitch_id: The switch ID. Required for switch manual mode.
        """
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        pulumi.set(__self__, "nat_route_entry_lists", nat_route_entry_lists)
        pulumi.set(__self__, "proxy_name", proxy_name)
        pulumi.set(__self__, "region_no", region_no)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if firewall_switch is not None:
            pulumi.set(__self__, "firewall_switch", firewall_switch)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if strict_mode is not None:
            pulumi.set(__self__, "strict_mode", strict_mode)
        if vswitch_auto is not None:
            pulumi.set(__self__, "vswitch_auto", vswitch_auto)
        if vswitch_cidr is not None:
            pulumi.set(__self__, "vswitch_cidr", vswitch_cidr)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Input[str]:
        """
        NAT gateway ID.
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natRouteEntryLists")
    def nat_route_entry_lists(self) -> pulumi.Input[Sequence[pulumi.Input['NatFirewallNatRouteEntryListArgs']]]:
        """
        The list of routes to be switched by the NAT gateway. See `nat_route_entry_list` below.
        """
        return pulumi.get(self, "nat_route_entry_lists")

    @nat_route_entry_lists.setter
    def nat_route_entry_lists(self, value: pulumi.Input[Sequence[pulumi.Input['NatFirewallNatRouteEntryListArgs']]]):
        pulumi.set(self, "nat_route_entry_lists", value)

    @property
    @pulumi.getter(name="proxyName")
    def proxy_name(self) -> pulumi.Input[str]:
        """
        NAT firewall name.
        """
        return pulumi.get(self, "proxy_name")

    @proxy_name.setter
    def proxy_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "proxy_name", value)

    @property
    @pulumi.getter(name="regionNo")
    def region_no(self) -> pulumi.Input[str]:
        """
        Region.
        """
        return pulumi.get(self, "region_no")

    @region_no.setter
    def region_no(self, value: pulumi.Input[str]):
        pulumi.set(self, "region_no", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The ID of the VPC instance.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="firewallSwitch")
    def firewall_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Safety protection switch. Value:-**open**: open-**close**: close.
        """
        return pulumi.get(self, "firewall_switch")

    @firewall_switch.setter
    def firewall_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firewall_switch", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        """
        Lang.
        """
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="strictMode")
    def strict_mode(self) -> Optional[pulumi.Input[int]]:
        """
        Whether strict mode is enabled 1-Enable strict mode 0-Disable strict mode.
        """
        return pulumi.get(self, "strict_mode")

    @strict_mode.setter
    def strict_mode(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "strict_mode", value)

    @property
    @pulumi.getter(name="vswitchAuto")
    def vswitch_auto(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to use switch automatic mode. Value: **true**: Use automatic mode: **false**: Use manual mode.
        """
        return pulumi.get(self, "vswitch_auto")

    @vswitch_auto.setter
    def vswitch_auto(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_auto", value)

    @property
    @pulumi.getter(name="vswitchCidr")
    def vswitch_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The network segment of the virtual switch. Required for Switch automatic mode.
        """
        return pulumi.get(self, "vswitch_cidr")

    @vswitch_cidr.setter
    def vswitch_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_cidr", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The switch ID. Required for switch manual mode.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


@pulumi.input_type
class _NatFirewallState:
    def __init__(__self__, *,
                 firewall_switch: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[str]] = None,
                 nat_route_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input['NatFirewallNatRouteEntryListArgs']]]] = None,
                 proxy_name: Optional[pulumi.Input[str]] = None,
                 region_no: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 strict_mode: Optional[pulumi.Input[int]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_auto: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NatFirewall resources.
        :param pulumi.Input[str] firewall_switch: Safety protection switch. Value:-**open**: open-**close**: close.
        :param pulumi.Input[str] lang: Lang.
        :param pulumi.Input[str] nat_gateway_id: NAT gateway ID.
        :param pulumi.Input[Sequence[pulumi.Input['NatFirewallNatRouteEntryListArgs']]] nat_route_entry_lists: The list of routes to be switched by the NAT gateway. See `nat_route_entry_list` below.
        :param pulumi.Input[str] proxy_name: NAT firewall name.
        :param pulumi.Input[str] region_no: Region.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[int] strict_mode: Whether strict mode is enabled 1-Enable strict mode 0-Disable strict mode.
        :param pulumi.Input[str] vpc_id: The ID of the VPC instance.
        :param pulumi.Input[str] vswitch_auto: Whether to use switch automatic mode. Value: **true**: Use automatic mode: **false**: Use manual mode.
        :param pulumi.Input[str] vswitch_cidr: The network segment of the virtual switch. Required for Switch automatic mode.
        :param pulumi.Input[str] vswitch_id: The switch ID. Required for switch manual mode.
        """
        if firewall_switch is not None:
            pulumi.set(__self__, "firewall_switch", firewall_switch)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_route_entry_lists is not None:
            pulumi.set(__self__, "nat_route_entry_lists", nat_route_entry_lists)
        if proxy_name is not None:
            pulumi.set(__self__, "proxy_name", proxy_name)
        if region_no is not None:
            pulumi.set(__self__, "region_no", region_no)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if strict_mode is not None:
            pulumi.set(__self__, "strict_mode", strict_mode)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_auto is not None:
            pulumi.set(__self__, "vswitch_auto", vswitch_auto)
        if vswitch_cidr is not None:
            pulumi.set(__self__, "vswitch_cidr", vswitch_cidr)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="firewallSwitch")
    def firewall_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Safety protection switch. Value:-**open**: open-**close**: close.
        """
        return pulumi.get(self, "firewall_switch")

    @firewall_switch.setter
    def firewall_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firewall_switch", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        """
        Lang.
        """
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[str]]:
        """
        NAT gateway ID.
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natRouteEntryLists")
    def nat_route_entry_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NatFirewallNatRouteEntryListArgs']]]]:
        """
        The list of routes to be switched by the NAT gateway. See `nat_route_entry_list` below.
        """
        return pulumi.get(self, "nat_route_entry_lists")

    @nat_route_entry_lists.setter
    def nat_route_entry_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NatFirewallNatRouteEntryListArgs']]]]):
        pulumi.set(self, "nat_route_entry_lists", value)

    @property
    @pulumi.getter(name="proxyName")
    def proxy_name(self) -> Optional[pulumi.Input[str]]:
        """
        NAT firewall name.
        """
        return pulumi.get(self, "proxy_name")

    @proxy_name.setter
    def proxy_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "proxy_name", value)

    @property
    @pulumi.getter(name="regionNo")
    def region_no(self) -> Optional[pulumi.Input[str]]:
        """
        Region.
        """
        return pulumi.get(self, "region_no")

    @region_no.setter
    def region_no(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_no", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="strictMode")
    def strict_mode(self) -> Optional[pulumi.Input[int]]:
        """
        Whether strict mode is enabled 1-Enable strict mode 0-Disable strict mode.
        """
        return pulumi.get(self, "strict_mode")

    @strict_mode.setter
    def strict_mode(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "strict_mode", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VPC instance.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchAuto")
    def vswitch_auto(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to use switch automatic mode. Value: **true**: Use automatic mode: **false**: Use manual mode.
        """
        return pulumi.get(self, "vswitch_auto")

    @vswitch_auto.setter
    def vswitch_auto(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_auto", value)

    @property
    @pulumi.getter(name="vswitchCidr")
    def vswitch_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The network segment of the virtual switch. Required for Switch automatic mode.
        """
        return pulumi.get(self, "vswitch_cidr")

    @vswitch_cidr.setter
    def vswitch_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_cidr", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The switch ID. Required for switch manual mode.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


class NatFirewall(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 firewall_switch: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[str]] = None,
                 nat_route_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NatFirewallNatRouteEntryListArgs', 'NatFirewallNatRouteEntryListArgsDict']]]]] = None,
                 proxy_name: Optional[pulumi.Input[str]] = None,
                 region_no: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 strict_mode: Optional[pulumi.Input[int]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_auto: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloud Firewall Nat Firewall resource.

        For information about Cloud Firewall Nat Firewall and how to use it, see [What is Nat Firewall](https://www.alibabacloud.com/help/zh/cloud-firewall/developer-reference/api-cloudfw-2017-12-07-createsecurityproxy).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        defaultik_z0g_d = alicloud.vpc.Network("defaultikZ0gD",
            cidr_block="172.16.0.0/12",
            vpc_name=name)
        defaultp4_o7qi = alicloud.vpc.Switch("defaultp4O7qi",
            vpc_id=defaultik_z0g_d.id,
            cidr_block="172.16.6.0/24",
            vswitch_name=name,
            zone_id=default.zones[0].id)
        default2i_r_zp_c = alicloud.vpc.NatGateway("default2iRZpC",
            eip_bind_mode="MULTI_BINDED",
            vpc_id=defaultik_z0g_d.id,
            nat_gateway_name=name,
            payment_type="PayAsYouGo",
            vswitch_id=defaultp4_o7qi.id,
            nat_type="Enhanced",
            network_type="internet")
        defaultyi_rwgs = alicloud.ecs.EipAddress("defaultyiRwgs", address_name=name)
        defaults2_m_tu_o = alicloud.ecs.EipAssociation("defaults2MTuO",
            instance_id=default2i_r_zp_c.id,
            allocation_id=defaultyi_rwgs.id,
            mode="NAT",
            instance_type="Nat")
        default_ake43g = alicloud.vpc.SnatEntry("defaultAKE43g",
            snat_ip=defaultyi_rwgs.ip_address,
            snat_table_id=default2i_r_zp_c.snat_table_ids,
            source_vswitch_id=defaultp4_o7qi.id)
        default_nat_firewall = alicloud.cloudfirewall.NatFirewall("default",
            nat_gateway_id=default2i_r_zp_c.id,
            nat_route_entry_lists=[{
                "nexthop_type": "NatGateway",
                "route_table_id": defaultik_z0g_d.route_table_id,
                "nexthop_id": default2i_r_zp_c.id,
                "destination_cidr": "0.0.0.0/0",
            }],
            firewall_switch="close",
            vswitch_auto="true",
            status="closed",
            region_no="cn-shenzhen",
            lang="zh",
            proxy_name="CFW-example",
            vswitch_id=default_ake43g.source_vswitch_id,
            strict_mode=0,
            vpc_id=defaultik_z0g_d.id,
            vswitch_cidr="172.16.5.0/24")
        ```

        ## Import

        Cloud Firewall Nat Firewall can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudfirewall/natFirewall:NatFirewall example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] firewall_switch: Safety protection switch. Value:-**open**: open-**close**: close.
        :param pulumi.Input[str] lang: Lang.
        :param pulumi.Input[str] nat_gateway_id: NAT gateway ID.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NatFirewallNatRouteEntryListArgs', 'NatFirewallNatRouteEntryListArgsDict']]]] nat_route_entry_lists: The list of routes to be switched by the NAT gateway. See `nat_route_entry_list` below.
        :param pulumi.Input[str] proxy_name: NAT firewall name.
        :param pulumi.Input[str] region_no: Region.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[int] strict_mode: Whether strict mode is enabled 1-Enable strict mode 0-Disable strict mode.
        :param pulumi.Input[str] vpc_id: The ID of the VPC instance.
        :param pulumi.Input[str] vswitch_auto: Whether to use switch automatic mode. Value: **true**: Use automatic mode: **false**: Use manual mode.
        :param pulumi.Input[str] vswitch_cidr: The network segment of the virtual switch. Required for Switch automatic mode.
        :param pulumi.Input[str] vswitch_id: The switch ID. Required for switch manual mode.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NatFirewallArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Firewall Nat Firewall resource.

        For information about Cloud Firewall Nat Firewall and how to use it, see [What is Nat Firewall](https://www.alibabacloud.com/help/zh/cloud-firewall/developer-reference/api-cloudfw-2017-12-07-createsecurityproxy).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        defaultik_z0g_d = alicloud.vpc.Network("defaultikZ0gD",
            cidr_block="172.16.0.0/12",
            vpc_name=name)
        defaultp4_o7qi = alicloud.vpc.Switch("defaultp4O7qi",
            vpc_id=defaultik_z0g_d.id,
            cidr_block="172.16.6.0/24",
            vswitch_name=name,
            zone_id=default.zones[0].id)
        default2i_r_zp_c = alicloud.vpc.NatGateway("default2iRZpC",
            eip_bind_mode="MULTI_BINDED",
            vpc_id=defaultik_z0g_d.id,
            nat_gateway_name=name,
            payment_type="PayAsYouGo",
            vswitch_id=defaultp4_o7qi.id,
            nat_type="Enhanced",
            network_type="internet")
        defaultyi_rwgs = alicloud.ecs.EipAddress("defaultyiRwgs", address_name=name)
        defaults2_m_tu_o = alicloud.ecs.EipAssociation("defaults2MTuO",
            instance_id=default2i_r_zp_c.id,
            allocation_id=defaultyi_rwgs.id,
            mode="NAT",
            instance_type="Nat")
        default_ake43g = alicloud.vpc.SnatEntry("defaultAKE43g",
            snat_ip=defaultyi_rwgs.ip_address,
            snat_table_id=default2i_r_zp_c.snat_table_ids,
            source_vswitch_id=defaultp4_o7qi.id)
        default_nat_firewall = alicloud.cloudfirewall.NatFirewall("default",
            nat_gateway_id=default2i_r_zp_c.id,
            nat_route_entry_lists=[{
                "nexthop_type": "NatGateway",
                "route_table_id": defaultik_z0g_d.route_table_id,
                "nexthop_id": default2i_r_zp_c.id,
                "destination_cidr": "0.0.0.0/0",
            }],
            firewall_switch="close",
            vswitch_auto="true",
            status="closed",
            region_no="cn-shenzhen",
            lang="zh",
            proxy_name="CFW-example",
            vswitch_id=default_ake43g.source_vswitch_id,
            strict_mode=0,
            vpc_id=defaultik_z0g_d.id,
            vswitch_cidr="172.16.5.0/24")
        ```

        ## Import

        Cloud Firewall Nat Firewall can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudfirewall/natFirewall:NatFirewall example <id>
        ```

        :param str resource_name: The name of the resource.
        :param NatFirewallArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NatFirewallArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 firewall_switch: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[str]] = None,
                 nat_route_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NatFirewallNatRouteEntryListArgs', 'NatFirewallNatRouteEntryListArgsDict']]]]] = None,
                 proxy_name: Optional[pulumi.Input[str]] = None,
                 region_no: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 strict_mode: Optional[pulumi.Input[int]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_auto: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NatFirewallArgs.__new__(NatFirewallArgs)

            __props__.__dict__["firewall_switch"] = firewall_switch
            __props__.__dict__["lang"] = lang
            if nat_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'nat_gateway_id'")
            __props__.__dict__["nat_gateway_id"] = nat_gateway_id
            if nat_route_entry_lists is None and not opts.urn:
                raise TypeError("Missing required property 'nat_route_entry_lists'")
            __props__.__dict__["nat_route_entry_lists"] = nat_route_entry_lists
            if proxy_name is None and not opts.urn:
                raise TypeError("Missing required property 'proxy_name'")
            __props__.__dict__["proxy_name"] = proxy_name
            if region_no is None and not opts.urn:
                raise TypeError("Missing required property 'region_no'")
            __props__.__dict__["region_no"] = region_no
            __props__.__dict__["status"] = status
            __props__.__dict__["strict_mode"] = strict_mode
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["vswitch_auto"] = vswitch_auto
            __props__.__dict__["vswitch_cidr"] = vswitch_cidr
            __props__.__dict__["vswitch_id"] = vswitch_id
        super(NatFirewall, __self__).__init__(
            'alicloud:cloudfirewall/natFirewall:NatFirewall',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            firewall_switch: Optional[pulumi.Input[str]] = None,
            lang: Optional[pulumi.Input[str]] = None,
            nat_gateway_id: Optional[pulumi.Input[str]] = None,
            nat_route_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NatFirewallNatRouteEntryListArgs', 'NatFirewallNatRouteEntryListArgsDict']]]]] = None,
            proxy_name: Optional[pulumi.Input[str]] = None,
            region_no: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            strict_mode: Optional[pulumi.Input[int]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vswitch_auto: Optional[pulumi.Input[str]] = None,
            vswitch_cidr: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None) -> 'NatFirewall':
        """
        Get an existing NatFirewall resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] firewall_switch: Safety protection switch. Value:-**open**: open-**close**: close.
        :param pulumi.Input[str] lang: Lang.
        :param pulumi.Input[str] nat_gateway_id: NAT gateway ID.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NatFirewallNatRouteEntryListArgs', 'NatFirewallNatRouteEntryListArgsDict']]]] nat_route_entry_lists: The list of routes to be switched by the NAT gateway. See `nat_route_entry_list` below.
        :param pulumi.Input[str] proxy_name: NAT firewall name.
        :param pulumi.Input[str] region_no: Region.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[int] strict_mode: Whether strict mode is enabled 1-Enable strict mode 0-Disable strict mode.
        :param pulumi.Input[str] vpc_id: The ID of the VPC instance.
        :param pulumi.Input[str] vswitch_auto: Whether to use switch automatic mode. Value: **true**: Use automatic mode: **false**: Use manual mode.
        :param pulumi.Input[str] vswitch_cidr: The network segment of the virtual switch. Required for Switch automatic mode.
        :param pulumi.Input[str] vswitch_id: The switch ID. Required for switch manual mode.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NatFirewallState.__new__(_NatFirewallState)

        __props__.__dict__["firewall_switch"] = firewall_switch
        __props__.__dict__["lang"] = lang
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["nat_route_entry_lists"] = nat_route_entry_lists
        __props__.__dict__["proxy_name"] = proxy_name
        __props__.__dict__["region_no"] = region_no
        __props__.__dict__["status"] = status
        __props__.__dict__["strict_mode"] = strict_mode
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_auto"] = vswitch_auto
        __props__.__dict__["vswitch_cidr"] = vswitch_cidr
        __props__.__dict__["vswitch_id"] = vswitch_id
        return NatFirewall(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="firewallSwitch")
    def firewall_switch(self) -> pulumi.Output[Optional[str]]:
        """
        Safety protection switch. Value:-**open**: open-**close**: close.
        """
        return pulumi.get(self, "firewall_switch")

    @property
    @pulumi.getter
    def lang(self) -> pulumi.Output[Optional[str]]:
        """
        Lang.
        """
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[str]:
        """
        NAT gateway ID.
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natRouteEntryLists")
    def nat_route_entry_lists(self) -> pulumi.Output[Sequence['outputs.NatFirewallNatRouteEntryList']]:
        """
        The list of routes to be switched by the NAT gateway. See `nat_route_entry_list` below.
        """
        return pulumi.get(self, "nat_route_entry_lists")

    @property
    @pulumi.getter(name="proxyName")
    def proxy_name(self) -> pulumi.Output[str]:
        """
        NAT firewall name.
        """
        return pulumi.get(self, "proxy_name")

    @property
    @pulumi.getter(name="regionNo")
    def region_no(self) -> pulumi.Output[str]:
        """
        Region.
        """
        return pulumi.get(self, "region_no")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="strictMode")
    def strict_mode(self) -> pulumi.Output[Optional[int]]:
        """
        Whether strict mode is enabled 1-Enable strict mode 0-Disable strict mode.
        """
        return pulumi.get(self, "strict_mode")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The ID of the VPC instance.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchAuto")
    def vswitch_auto(self) -> pulumi.Output[Optional[str]]:
        """
        Whether to use switch automatic mode. Value: **true**: Use automatic mode: **false**: Use manual mode.
        """
        return pulumi.get(self, "vswitch_auto")

    @property
    @pulumi.getter(name="vswitchCidr")
    def vswitch_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        The network segment of the virtual switch. Required for Switch automatic mode.
        """
        return pulumi.get(self, "vswitch_cidr")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[Optional[str]]:
        """
        The switch ID. Required for switch manual mode.
        """
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FaceConfigArgs', 'FaceConfig']

@pulumi.input_type
class FaceConfigArgs:
    def __init__(__self__, *,
                 biz_name: pulumi.Input[str],
                 biz_type: pulumi.Input[str]):
        """
        The set of arguments for constructing a FaceConfig resource.
        :param pulumi.Input[str] biz_name: Scene name.
        :param pulumi.Input[str] biz_type: Scene type. **NOTE:** The biz_type cannot exceed 32 characters and can only use English letters, numbers and dashes (-).
        """
        pulumi.set(__self__, "biz_name", biz_name)
        pulumi.set(__self__, "biz_type", biz_type)

    @property
    @pulumi.getter(name="bizName")
    def biz_name(self) -> pulumi.Input[str]:
        """
        Scene name.
        """
        return pulumi.get(self, "biz_name")

    @biz_name.setter
    def biz_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "biz_name", value)

    @property
    @pulumi.getter(name="bizType")
    def biz_type(self) -> pulumi.Input[str]:
        """
        Scene type. **NOTE:** The biz_type cannot exceed 32 characters and can only use English letters, numbers and dashes (-).
        """
        return pulumi.get(self, "biz_type")

    @biz_type.setter
    def biz_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "biz_type", value)


@pulumi.input_type
class _FaceConfigState:
    def __init__(__self__, *,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 biz_type: Optional[pulumi.Input[str]] = None,
                 gmt_modified: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering FaceConfig resources.
        :param pulumi.Input[str] biz_name: Scene name.
        :param pulumi.Input[str] biz_type: Scene type. **NOTE:** The biz_type cannot exceed 32 characters and can only use English letters, numbers and dashes (-).
        :param pulumi.Input[str] gmt_modified: Last Modified Date.
        """
        if biz_name is not None:
            pulumi.set(__self__, "biz_name", biz_name)
        if biz_type is not None:
            pulumi.set(__self__, "biz_type", biz_type)
        if gmt_modified is not None:
            pulumi.set(__self__, "gmt_modified", gmt_modified)

    @property
    @pulumi.getter(name="bizName")
    def biz_name(self) -> Optional[pulumi.Input[str]]:
        """
        Scene name.
        """
        return pulumi.get(self, "biz_name")

    @biz_name.setter
    def biz_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_name", value)

    @property
    @pulumi.getter(name="bizType")
    def biz_type(self) -> Optional[pulumi.Input[str]]:
        """
        Scene type. **NOTE:** The biz_type cannot exceed 32 characters and can only use English letters, numbers and dashes (-).
        """
        return pulumi.get(self, "biz_type")

    @biz_type.setter
    def biz_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_type", value)

    @property
    @pulumi.getter(name="gmtModified")
    def gmt_modified(self) -> Optional[pulumi.Input[str]]:
        """
        Last Modified Date.
        """
        return pulumi.get(self, "gmt_modified")

    @gmt_modified.setter
    def gmt_modified(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gmt_modified", value)


class FaceConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 biz_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloudauth Face Config resource.

        For information about Cloudauth Face Config and how to use it, see [What is Face Config](https://help.aliyun.com/zh/id-verification/cloudauth/product-overview/end-of-integration-announcement-on-id-verification).

        > **NOTE:** Available since v1.137.0.

        > **NOTE:** In order to provide you with more perfect product capabilities, the real person certification service has stopped access, it is recommended that you use the upgraded version of the [real person certification financial real person certification service](https://help.aliyun.com/zh/id-verification/product-overview/what-is-id-verification-for-financial-services). Users that have access to real person authentication are not affected.

        ## Import

        Cloudauth Face Config can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudauth/faceConfig:FaceConfig example <lang>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] biz_name: Scene name.
        :param pulumi.Input[str] biz_type: Scene type. **NOTE:** The biz_type cannot exceed 32 characters and can only use English letters, numbers and dashes (-).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FaceConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloudauth Face Config resource.

        For information about Cloudauth Face Config and how to use it, see [What is Face Config](https://help.aliyun.com/zh/id-verification/cloudauth/product-overview/end-of-integration-announcement-on-id-verification).

        > **NOTE:** Available since v1.137.0.

        > **NOTE:** In order to provide you with more perfect product capabilities, the real person certification service has stopped access, it is recommended that you use the upgraded version of the [real person certification financial real person certification service](https://help.aliyun.com/zh/id-verification/product-overview/what-is-id-verification-for-financial-services). Users that have access to real person authentication are not affected.

        ## Import

        Cloudauth Face Config can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudauth/faceConfig:FaceConfig example <lang>
        ```

        :param str resource_name: The name of the resource.
        :param FaceConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FaceConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 biz_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FaceConfigArgs.__new__(FaceConfigArgs)

            if biz_name is None and not opts.urn:
                raise TypeError("Missing required property 'biz_name'")
            __props__.__dict__["biz_name"] = biz_name
            if biz_type is None and not opts.urn:
                raise TypeError("Missing required property 'biz_type'")
            __props__.__dict__["biz_type"] = biz_type
            __props__.__dict__["gmt_modified"] = None
        super(FaceConfig, __self__).__init__(
            'alicloud:cloudauth/faceConfig:FaceConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            biz_name: Optional[pulumi.Input[str]] = None,
            biz_type: Optional[pulumi.Input[str]] = None,
            gmt_modified: Optional[pulumi.Input[str]] = None) -> 'FaceConfig':
        """
        Get an existing FaceConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] biz_name: Scene name.
        :param pulumi.Input[str] biz_type: Scene type. **NOTE:** The biz_type cannot exceed 32 characters and can only use English letters, numbers and dashes (-).
        :param pulumi.Input[str] gmt_modified: Last Modified Date.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FaceConfigState.__new__(_FaceConfigState)

        __props__.__dict__["biz_name"] = biz_name
        __props__.__dict__["biz_type"] = biz_type
        __props__.__dict__["gmt_modified"] = gmt_modified
        return FaceConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bizName")
    def biz_name(self) -> pulumi.Output[str]:
        """
        Scene name.
        """
        return pulumi.get(self, "biz_name")

    @property
    @pulumi.getter(name="bizType")
    def biz_type(self) -> pulumi.Output[str]:
        """
        Scene type. **NOTE:** The biz_type cannot exceed 32 characters and can only use English letters, numbers and dashes (-).
        """
        return pulumi.get(self, "biz_type")

    @property
    @pulumi.getter(name="gmtModified")
    def gmt_modified(self) -> pulumi.Output[str]:
        """
        Last Modified Date.
        """
        return pulumi.get(self, "gmt_modified")

